@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tab-bar-notch" "0.0.7"
+(define-package "tab-bar-notch" "20241224.109"
   "Adjust tab-bar height for MacBook Pro notch."
   '((emacs "27.1"))
   :url "https://github.com/jimeh/tab-bar-notch"
